@@ -2,7 +2,7 @@
 fraction.py
 this script is response for the operation in fraction.
 """
-from wmath.number_theory import *
+from wmath.number_theory import greatest_common_divisor
 
 
 class Fraction:
@@ -59,31 +59,31 @@ class Fraction:
     def __add__(self, other):
         _denominator = self.denominator * other.denominator
         _molecule = self.molecule * other.denominator + other.molecule * self.denominator
-        return Fraction(int(_molecule), int(_denominator))
+        return Fraction(_molecule, _denominator)
 
     def __sub__(self, other):
         _denominator = self.denominator * other.denominator
         _molecule = self.molecule * other.denominator - other.molecule * self.denominator
-        return Fraction(int(_molecule), int(_denominator))
+        return Fraction(_molecule, _denominator)
 
     def __mul__(self, other):
         _denominator = self.denominator * other.denominator
         _molecule = self.molecule * other.molecule
-        return Fraction(int(_molecule), int(_denominator))
+        return Fraction(_molecule, _denominator)
 
     def __truediv__(self, other):
         _denominator = self.denominator * other.molecule
         _molecule = self.molecule * other.denominator
-        return Fraction(int(_molecule), int(_denominator))
+        return Fraction(_molecule, _denominator)
 
-    def __pow__(self, power, modulo=None):
+    def __pow__(self, power: int, modulo=None):
         _denominator = pow(self.denominator, power)
         _molecule = 0
         if modulo:
             _molecule = pow(self.molecule, power, modulo * _denominator)
         else:
             _molecule = pow(self.molecule, power)
-        return Fraction(int(_molecule), int(_denominator))
+        return Fraction(_molecule, _denominator)
 
     def formula(self):
         """
