@@ -3,8 +3,11 @@ polynomial.py
 this script is response for the related problems in rational polynomial.
 """
 import copy
-from wmath.number_theory import *
-from wmath.fraction import *
+from wmath.number_theory import (greatest_common_divisor_in_list,
+                                 least_common_multiple_in_list,
+                                 prime_factor_without_exp,
+                                 factor)
+from wmath.fraction import Fraction
 
 
 class Polynomial:
@@ -110,6 +113,21 @@ class Polynomial:
     def __mod__(self, other):
         return (self / other)[1]
 
+    def __pow__(self, power: int, modulo=None):
+        _self = copy.deepcopy(self)
+        _pow = Polynomial([Fraction(1, 1)])
+        while power:
+            if modulo:
+                if power & 1:
+                    _pow = _pow * _self % modulo
+                _self = _self * _self % modulo
+            else:
+                if power & 1:
+                    _pow *= _self
+                _self *= _self
+            power >>= 1
+        return _pow
+
     def value(self, x: Fraction):
         """
         calc the value of the corresponding polynomial function where x is designated.
@@ -186,8 +204,8 @@ class Polynomial:
             return []
         if _self.degree == 1:
             return [-_self.coefficient[0] / _self.coefficient[1]]
-        _molecule_list = factor_without_exp(_self.coefficient[0].molecule)
-        _denominator_list = factor_without_exp(_self.coefficient[-1].molecule)
+        _molecule_list = factor(_self.coefficient[0].molecule)
+        _denominator_list = factor(_self.coefficient[-1].molecule)
         _rational_roots = []
         for _molecule in _molecule_list:
             for _denominator in _denominator_list:
@@ -215,10 +233,7 @@ class Polynomial:
         """
         _self = copy.deepcopy(self).primitive()
         _part_coefficient_list = [_i.molecule for _i in _self.coefficient][:-1]
-        _prime_list = factor_without_exp(
-            greatest_common_divisor_in_list(
-                _part_coefficient_list))
-        _prime_list.remove(1)
+        _prime_list = prime_factor_without_exp(greatest_common_divisor_in_list(_part_coefficient_list))
         if _prime_list:
             for _prime in _prime_list:
                 if _self.coefficient[-1].molecule % _prime and _self.coefficient[0].molecule % _prime ** 2:
